@@ -9,9 +9,10 @@
  * Covariate class.
  *****************************************************************************/
 
+#include "Covariate.h"
 #include <cmath>
 
-#include "Covariate.h"
+using namespace std;
 
 namespace siena
 {
@@ -23,10 +24,11 @@ namespace siena
 /**
  * Creates a new covariate with the given name for the given set of actors.
  */
-Covariate::Covariate(std::string name, const ActorSet * pActorSet) :
+Covariate::Covariate(string name, const ActorSet * pActorSet) :
 	NamedObject(name)
 {
 	this->lpActorSet = pActorSet;
+	this->lmean = 0;
 	this->lrange = 0;
 	this->lsimilarityMean = 0;
 }
@@ -45,6 +47,14 @@ const ActorSet * Covariate::pActorSet() const
 }
 
 
+/**
+ * Stores the average value of this covariate.
+ */
+void Covariate::mean(double value)
+{
+	this->lmean = value;
+}
+
 /**
  * Stores the range of values of this covariate, which is calculated in R.
  */
@@ -53,7 +63,6 @@ void Covariate::range(double range)
 	this->lrange = range;
 }
 
-
 /**
  * Stores the similarity mean of this covariate, which is calculated in R.
  */
@@ -66,7 +75,7 @@ void Covariate::similarityMean(double similarityMean)
  * Stores the similarity alter mean of this covariate wrt this network,
  * which is calculated in R.
  */
-void Covariate::similarityMeans(double similarityMean, std::string networkName)
+void Covariate::similarityMeans(double similarityMean, string networkName)
 {
 	this->lsimilarityMeans[networkName] = similarityMean;
 }
@@ -91,7 +100,7 @@ double Covariate::similarity(double a, double b) const
 double Covariate::similarityNetwork(double a, double b, string networkName) const
 {
 	double similarityMean = 0;
-	map<std::string, double>::const_iterator iter =
+	map<string, double>::const_iterator iter =
 		this->lsimilarityMeans.find(networkName);
 	if (iter != this->lsimilarityMeans.end())
 	{
