@@ -23,11 +23,14 @@ namespace siena
 class AverageReciprocatedAlterEffect : public NetworkDependentBehaviorEffect
 {
 public:
-	AverageReciprocatedAlterEffect(const EffectInfo * pEffectInfo);
+	AverageReciprocatedAlterEffect(const EffectInfo * pEffectInfo, bool divide);
 
 	virtual double calculateChangeContribution(int actor,
 		int difference);
 	virtual double egoStatistic(int ego, double * currentValues);
+private:
+	// divide indicates whether there will be division by the outdegree
+	bool ldivide;
 };
 
 }
