@@ -26,11 +26,14 @@
 #include "model/effects/generic/InDegreeFunction.h"
 #include "model/effects/generic/IntSqrtFunction.h"
 #include "model/effects/generic/DifferenceFunction.h"
+#include "model/effects/generic/AbsDiffFunction.h"
 #include "model/effects/generic/SumFunction.h"
 #include "model/effects/generic/EgoFunction.h"
 #include "model/effects/generic/EgoInDegreeFunction.h"
 #include "model/effects/generic/OutDegreeFunction.h"
 #include "model/effects/generic/EgoOutDegreeFunction.h"
+#include "model/effects/generic/EgoRecipDegreeFunction.h"
+#include "model/effects/generic/DegreeFunction.h"
 #include "model/effects/generic/BetweennessFunction.h"
 #include "model/effects/generic/GwespFunction.h"
 #include "model/effects/generic/InStarFunction.h"
@@ -355,6 +358,10 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	{
 		pEffect = new BothDegreesEffect(pEffectInfo, true);
 	}
+	else if (effectName == "avDeg")
+	{
+		pEffect = new AverageDegreeEffect(pEffectInfo);
+	}
 	else if (effectName == "outTrunc")
 	{
 		pEffect = new TruncatedOutdegreeEffect(pEffectInfo, true, false);
@@ -395,6 +402,54 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	{
 		pEffect = new InInDegreeAssortativityEffect(pEffectInfo);
 	}
+	else if (effectName == "outAct_ego")
+	{
+		string networkName = pEffectInfo->variableName();
+		AlterFunction * pFirstFunction =
+			new EgoOutDegreeFunction(pEffectInfo->variableName());
+		ConstantFunction * pSecondFunction =
+			new ConstantFunction(pEffectInfo->variableName(),
+				AVERAGE_OUT_DEGREE);
+		if (pEffectInfo->internalEffectParameter() == 2)
+		{
+			pFirstFunction = new IntSqrtFunction(pFirstFunction);
+			pSecondFunction->pFunction(sqrt);
+		}
+		pEffect = new GenericNetworkEffect(pEffectInfo,
+			new DifferenceFunction(pFirstFunction, pSecondFunction));
+	}
+	else if (effectName == "inAct_ego")
+	{
+		string networkName = pEffectInfo->variableName();
+		AlterFunction * pFirstFunction =
+			new EgoInDegreeFunction(pEffectInfo->variableName());
+		ConstantFunction * pSecondFunction =
+			new ConstantFunction(pEffectInfo->variableName(),
+				AVERAGE_IN_DEGREE);
+		if (pEffectInfo->internalEffectParameter() == 2)
+		{
+			pFirstFunction = new IntSqrtFunction(pFirstFunction);
+			pSecondFunction->pFunction(sqrt);
+		}
+		pEffect = new GenericNetworkEffect(pEffectInfo,
+			new DifferenceFunction(pFirstFunction, pSecondFunction));
+	}
+	else if (effectName == "reciAct_ego")
+	{
+		string networkName = pEffectInfo->variableName();
+		AlterFunction * pFirstFunction =
+			new EgoRecipDegreeFunction(pEffectInfo->variableName());
+		ConstantFunction * pSecondFunction =
+			new ConstantFunction(pEffectInfo->variableName(),
+				AVERAGE_RECIP_DEGREE);
+		if (pEffectInfo->internalEffectParameter() == 2)
+		{
+			pFirstFunction = new IntSqrtFunction(pFirstFunction);
+			pSecondFunction->pFunction(sqrt);
+		}
+		pEffect = new GenericNetworkEffect(pEffectInfo,
+			new DifferenceFunction(pFirstFunction, pSecondFunction));
+	}
 	else if (effectName == "X")
 	{
 		pEffect = new DyadicCovariateMainEffect(pEffectInfo);
@@ -435,6 +490,10 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	{
 		pEffect = new XWXClosureEffect(pEffectInfo, false, true);
 	}
+	else if (effectName == "XXW")
+	{
+		pEffect = new XXWClosureEffect(pEffectInfo, true, true);
+	}
 	else if (effectName == "altX")
 	{
 		pEffect = new CovariateAlterEffect(pEffectInfo, false, false, false);
@@ -817,6 +876,25 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 		pEffect = new GenericNetworkEffect(pEffectInfo,
 			new DifferenceFunction(pFirstFunction, pSecondFunction));
 	}
+    else if (effectName == "crprodInActIntn")
+    {
+        AlterFunction * pFirstFunction =
+            new EgoInDegreeFunction(pEffectInfo->interactionName1());
+        ConstantFunction * pSecondFunction =
+            new ConstantFunction(pEffectInfo->interactionName1(),
+                AVERAGE_IN_DEGREE);
+
+        if (pEffectInfo->internalEffectParameter() == 2)
+        {
+            pFirstFunction = new IntSqrtFunction(pFirstFunction);
+            pSecondFunction->pFunction(sqrt);
+        }
+
+        pEffect = new GenericNetworkEffect(pEffectInfo,
+            new ProductFunction(
+                new OutTieFunction(pEffectInfo->interactionName1()),
+                new DifferenceFunction(pFirstFunction, pSecondFunction)));
+    }
 	else if (effectName == "outPopIntn")
 	{
 		AlterFunction * pFirstFunction =
@@ -851,6 +929,28 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 		pEffect = new GenericNetworkEffect(pEffectInfo,
 			new DifferenceFunction(pFirstFunction, pSecondFunction));
 	}
+	else if (effectName == "absOutDiffIntn")
+	{
+		AlterFunction * pAlterOutdegreeFunction =
+			new OutDegreeFunction(pEffectInfo->interactionName1());
+		AlterFunction * pEgoOutdegreeFunction =
+			new EgoOutDegreeFunction(pEffectInfo->interactionName1());
+		if (pEffectInfo->internalEffectParameter() == 2)
+		{
+			pAlterOutdegreeFunction =
+				new IntSqrtFunction(pAlterOutdegreeFunction);
+			pEgoOutdegreeFunction =
+				new IntSqrtFunction(pEgoOutdegreeFunction);
+		}
+		pEffect = new GenericNetworkEffect(pEffectInfo,
+			new AbsDiffFunction(pAlterOutdegreeFunction,pEgoOutdegreeFunction));
+	}
+	else if (effectName == "avDegIntn")
+	{
+		pEffect = new GenericNetworkEffect(pEffectInfo,
+						new DegreeFunction(pEffectInfo->interactionName1(), 
+									pEffectInfo->internalEffectParameter()));
+	}
 	else if (effectName == "doubleOutAct")
 	{
 		string firstNetworkName = pEffectInfo->variableName();
@@ -942,7 +1042,6 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 		ConstantFunction * pSecondConstantFunction =
 			new ConstantFunction(pEffectInfo->interactionName1(),
 				AVERAGE_IN_DEGREE);
-
 		if (pEffectInfo->internalEffectParameter() == 2)
 		{
 			pAlterIndegreeFunction =
@@ -952,7 +1051,6 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 			pFirstConstantFunction->pFunction(sqrt);
 			pSecondConstantFunction->pFunction(sqrt);
 		}
-
 		pEffect = new GenericNetworkEffect(pEffectInfo,
 			new ProductFunction(
 				new DifferenceFunction(pAlterIndegreeFunction,
@@ -990,7 +1088,7 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 				new MixedTwoStepFunction(
 						pEffectInfo->interactionName1(),
 						pEffectInfo->variableName(),
-						FORWARD, FORWARD, (pEffectInfo->internalEffectParameter()>=2)));
+						FORWARD, FORWARD, pEffectInfo->internalEffectParameter()));
 	}
 	else if (effectName == "toBack") // formerly mixedInWX
 	{
@@ -998,7 +1096,7 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 				new MixedTwoStepFunction(
 						pEffectInfo->interactionName1(),
 						pEffectInfo->variableName(),
-						BACKWARD, FORWARD, (pEffectInfo->internalEffectParameter()>=2)));
+						BACKWARD, FORWARD, pEffectInfo->internalEffectParameter()));
 		}
 	else if (effectName == "toRecip")
 	{
@@ -1006,8 +1104,12 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 				new MixedTwoStepFunction(
 						pEffectInfo->interactionName1(),
 						pEffectInfo->variableName(),
-						RECIPROCAL, FORWARD, (pEffectInfo->internalEffectParameter()>=2)));
-		}
+						RECIPROCAL, FORWARD, pEffectInfo->internalEffectParameter()));
+	}
+	else if (effectName == "toAny")
+	{
+		pEffect = new MixedOnlyTwoPathEffect(pEffectInfo);
+	}
 	else if (effectName == "cl.XWX")
 	{
 		pEffect = new GenericNetworkEffect(pEffectInfo,
@@ -1015,11 +1117,11 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 			new MixedTwoStepFunction(
 						pEffectInfo->variableName(),
 						pEffectInfo->interactionName1(),
-						FORWARD, FORWARD, false),
+						FORWARD, FORWARD, 0),
 			new MixedTwoStepFunction(
 						pEffectInfo->variableName(),
 						pEffectInfo->interactionName1(),
-						FORWARD, BACKWARD, false)));
+						FORWARD, BACKWARD, 0)));
 	}
 	else if (effectName == "cl.XWX1")
 	{
@@ -1027,7 +1129,7 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 					new MixedTwoStepFunction(
 						pEffectInfo->variableName(),
 						pEffectInfo->interactionName1(),
-						FORWARD, FORWARD, false));
+						FORWARD, FORWARD, 0));
 	}
 	else if (effectName == "cl.XWX2")
 	{
@@ -1035,7 +1137,7 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 			new  MixedTwoStepFunction(
 						pEffectInfo->variableName(),
 						pEffectInfo->interactionName1(),
-						FORWARD, BACKWARD, false));
+						FORWARD, BACKWARD, 0));
 	}
 	else if (effectName == "mixedInXW")
 	{
@@ -1043,7 +1145,7 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 				new MixedTwoStepFunction(
 						pEffectInfo->variableName(),
 						pEffectInfo->interactionName1(),
-						BACKWARD, FORWARD, (pEffectInfo->internalEffectParameter()>=2)));
+						BACKWARD, FORWARD, pEffectInfo->internalEffectParameter()));
 	}
 	/*
 	 * Mixed two step effects with flexible iterators (added by Christoph)
@@ -1059,69 +1161,76 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 		pEffect = new GenericNetworkEffect(pEffectInfo,
 			new MixedTwoStepFunction(pEffectInfo->variableName(), // not mixed, TwoStepFunction equivalent not implemented
 					pEffectInfo->variableName(),
-					EITHER, EITHER, false));
+					EITHER, EITHER, 0));
 	}
 	else if (effectName == "transTrip.FE")
 	{
 		pEffect = new GenericNetworkEffect(pEffectInfo,
 			new MixedTwoStepFunction(pEffectInfo->variableName(), // not mixed, TwoStepFunction equivalent not implemented
 					pEffectInfo->variableName(),
-					FORWARD, EITHER, false));
+					FORWARD, EITHER, 0));
 	}
 	else if (effectName == "WWX.EE")
 	{
 		pEffect = new GenericNetworkEffect(pEffectInfo,
 			new MixedTwoStepFunction(pEffectInfo->interactionName1(), // not mixed
 					pEffectInfo->interactionName1(),
-					EITHER, EITHER, false));
+					EITHER, EITHER, 0));
 	}
 	else if (effectName == "WXX.FE")
 	{
 		pEffect = new GenericNetworkEffect(pEffectInfo,
 			new MixedTwoStepFunction(pEffectInfo->interactionName1(),
 					pEffectInfo->variableName(),
-					FORWARD, EITHER, false));
+					FORWARD, EITHER, 0));
 	}
 	else if (effectName == "XWX.ER")
 	{
 		pEffect = new GenericNetworkEffect(pEffectInfo,
 			new MixedTwoStepFunction(pEffectInfo->variableName(),
 					pEffectInfo->interactionName1(),
-					EITHER, RECIPROCAL, false));
+					EITHER, RECIPROCAL, 0));
 	}
 	else if (effectName == "WWX.FR")
 	{
 		pEffect = new GenericNetworkEffect(pEffectInfo,
 			new MixedTwoStepFunction(pEffectInfo->interactionName1(),  // not mixed
 					pEffectInfo->interactionName1(),
-					FORWARD, RECIPROCAL, false));
+					FORWARD, RECIPROCAL, 0));
 	}
 	else if (effectName == "WXX.ER")
 	{
 		pEffect = new GenericNetworkEffect(pEffectInfo,
 			new MixedTwoStepFunction(pEffectInfo->interactionName1(),
 					pEffectInfo->variableName(),
-					EITHER, RECIPROCAL, false));
+					EITHER, RECIPROCAL, 0));
 	}
 	else if (effectName == "XWX.FE")
 	{
 		pEffect = new GenericNetworkEffect(pEffectInfo,
 			new MixedTwoStepFunction(pEffectInfo->variableName(),
 					pEffectInfo->interactionName1(),
-					FORWARD, EITHER, false));
+					FORWARD, EITHER, 0));
 	}
 	else if (effectName == "outOutActIntn")
 	{
 		pEffect = new GenericNetworkEffect(pEffectInfo,
 			new OutActDistance2Function(pEffectInfo->interactionName1(),
 							pEffectInfo->variableName(),
-							pEffectInfo->internalEffectParameter(), false, false));
+							pEffectInfo->internalEffectParameter(), false, false, false));
+	}
+	else if (effectName == "outOutAvIntn")
+	{
+		pEffect = new GenericNetworkEffect(pEffectInfo,
+			new OutActDistance2Function(pEffectInfo->interactionName1(),
+							pEffectInfo->variableName(),
+							pEffectInfo->internalEffectParameter(), false, false, true));
 	}
 	else if (effectName == "sharedTo")
 	{
 		pEffect = new GenericNetworkEffect(pEffectInfo,
-						new MixedThreeCyclesFunction(pEffectInfo->variableName(),
-							pEffectInfo->interactionName1(),
+						new MixedThreeCyclesFunction(pEffectInfo->interactionName1(),
+							pEffectInfo->variableName(),
 							pEffectInfo->internalEffectParameter()));
 	}
 	else if (effectName == "toU")
@@ -1411,11 +1520,19 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	{
 		pEffect = new ConstantEffect(pEffectInfo);
 	}
-	else if ((effectName == "threshold") | (effectName == "threshold2") |
-	         (effectName == "threshold3") |(effectName == "threshold4"))
+	else if ((effectName == "threshold") || (effectName == "threshold2") ||
+	         (effectName == "threshold3") || (effectName == "threshold4"))
 	{
 		pEffect = new ThresholdShapeEffect(pEffectInfo);
 	}
+	else if (effectName == "simAllNear")
+	{
+		pEffect = new AllSimilarityEffect(pEffectInfo, true);
+	}
+	else if (effectName == "simAllFar")
+	{
+		pEffect = new AllSimilarityEffect(pEffectInfo, false);
+	}
 	else if (effectName == "avSim")
 	{
 		pEffect = new SimilarityEffect(pEffectInfo, true, false, false, true, true);
@@ -1528,49 +1645,93 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	{
 		pEffect = new InIsolateDegreeEffect(pEffectInfo);
 	}
+	else if (effectName == "nonPrimary")
+	{
+		pEffect = new PrimaryCompressionEffect(pEffectInfo, false, false);
+	}
+	else if (effectName == "nonPCompress")
+	{
+		pEffect = new PrimaryCompressionEffect(pEffectInfo, false, true);
+	}
+	else if (effectName == "primary")
+	{
+		pEffect = new PrimaryCompressionEffect(pEffectInfo, true, false);
+	}
+	else if (effectName == "primCompress")
+	{
+		pEffect = new PrimaryCompressionEffect(pEffectInfo, true, true);
+	}
+	else if (effectName == "primDegAct")
+	{
+		pEffect = new PrimarySettingEffect(pEffectInfo, false, false, false, false);
+	}
+	else if (effectName == "primDegActDiff")
+	{
+		pEffect = new PrimarySettingEffect(pEffectInfo, true, false, false, false);
+	}
+	else if (effectName == "primDegActDiffSqrt")
+	{
+		pEffect = new PrimarySettingEffect(pEffectInfo, true, false, true, false);
+	}
+	else if (effectName == "primDegActSqrt")
+	{
+		pEffect = new PrimarySettingEffect(pEffectInfo, false, false, true, false);
+	}
+	else if (effectName == "primDegActLog")
+	{
+		pEffect = new PrimarySettingEffect(pEffectInfo, false, true, false, false);
+	}
+	else if (effectName == "primDegActInv")
+	{
+		pEffect = new PrimarySettingEffect(pEffectInfo, false, false, false, true);
+	}
 	else if (effectName == "settingSizeAct")
 	{
-		pEffect = new SettingSizeEffect(pEffectInfo, false, false, false, false, false);
+		pEffect = new SettingSizeEffect(pEffectInfo, false, false, false, false, false, false);
 	}
 	else if (effectName == "settingSizeActSqrt")
 	{
-		pEffect = new SettingSizeEffect(pEffectInfo, false, false, true, false, false);
+		pEffect = new SettingSizeEffect(pEffectInfo, false, false, true, false, false, false);
 	}
 	else if (effectName == "settingSizeActLog")
 	{
-		pEffect = new SettingSizeEffect(pEffectInfo, false, true, false, false, false);
+		pEffect = new SettingSizeEffect(pEffectInfo, false, true, false, false, false, false);
+	}
+	else if (effectName == "settingSizeActInv")
+	{
+		pEffect = new SettingSizeEffect(pEffectInfo, false, false, false, true, false, false);
 	}
 	else if (effectName == "settingOppAct")
 	{
-		pEffect = new SettingSizeEffect(pEffectInfo, true, false, false, false, false);
+		pEffect = new SettingSizeEffect(pEffectInfo, true, false, false, false, false, false);
 	}
 	else if (effectName == "settingOppActSqrt")
 	{
-		pEffect = new SettingSizeEffect(pEffectInfo, true, false, true, false, false);
+		pEffect = new SettingSizeEffect(pEffectInfo, true, false, true, false, false, false);
 	}
 	else if (effectName == "settingOppActLog")
 	{
-		pEffect = new SettingSizeEffect(pEffectInfo, true, true, false, false, false);
+		pEffect = new SettingSizeEffect(pEffectInfo, true, true, false, false, false, false);
 	}
 	else if (effectName == "settingLogCreationAct")
 	{
-		pEffect = new SettingSizeEffect(pEffectInfo, true, true, false, true, false);
+		pEffect = new SettingSizeEffect(pEffectInfo, true, true, false, false, true, false);
 	}
 	else if (effectName == "settingOppActD")
 	{
-		pEffect = new SettingSizeEffect(pEffectInfo, true, false, false, false, true);
+		pEffect = new SettingSizeEffect(pEffectInfo, true, false, false, false, false, true);
 	}
 	else if (effectName == "settingOppActSqrtD")
 	{
-		pEffect = new SettingSizeEffect(pEffectInfo, true, false, true, false, true);
+		pEffect = new SettingSizeEffect(pEffectInfo, true, false, true, false, false, true);
 	}
 	else if (effectName == "settingOppActLogD")
 	{
-		pEffect = new SettingSizeEffect(pEffectInfo, true, true, false, false, true);
+		pEffect = new SettingSizeEffect(pEffectInfo, true, true, false, false, false, true);
 	}
 	else if (effectName == "settingLogCreationActD")
 	{
-		pEffect = new SettingSizeEffect(pEffectInfo, true, true, false, true, true);
+		pEffect = new SettingSizeEffect(pEffectInfo, true, true, false, false, true, true);
 	}
 	else if (effectName == "avSimRecip")
 	{
@@ -1893,19 +2054,35 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	}
 	else if (effectName == "avWAlt")
 	{
-		pEffect = new DyadicCovariateAvAltEffect(pEffectInfo,true, false);
+		pEffect = new DyadicCovariateAvAltEffect(pEffectInfo,true, false, true);
+	}
+	else if (effectName == "avWInAlt")
+	{
+		pEffect = new DyadicCovariateAvAltEffect(pEffectInfo,true, false, false);
 	}
 	else if (effectName == "totWAlt")
 	{
-		pEffect = new DyadicCovariateAvAltEffect(pEffectInfo,false, false);
+		pEffect = new DyadicCovariateAvAltEffect(pEffectInfo,false, false, true);
+	}
+	else if (effectName == "totWInAlt")
+	{
+		pEffect = new DyadicCovariateAvAltEffect(pEffectInfo,false, false, false);
 	}
 	else if (effectName == "avAltW")
 	{
-		pEffect = new DyadicCovariateAvAltEffect(pEffectInfo,true, true);
+		pEffect = new DyadicCovariateAvAltEffect(pEffectInfo,true, true, true);
+	}
+	else if (effectName == "avInAltW")
+	{
+		pEffect = new DyadicCovariateAvAltEffect(pEffectInfo,true, true, false);
 	}
 	else if (effectName == "totAltW")
 	{
-		pEffect = new DyadicCovariateAvAltEffect(pEffectInfo,false, true);
+		pEffect = new DyadicCovariateAvAltEffect(pEffectInfo,false, true, true);
+	}
+	else if (effectName == "totInAltW")
+	{
+		pEffect = new DyadicCovariateAvAltEffect(pEffectInfo,false, true, false);
 	}
 	else if (effectName == "avSimW")
 	{
