@@ -14,7 +14,9 @@
 #include <stdexcept>
 #include <R_ext/Print.h>
 #include <R_ext/Arith.h>
-//#include <Rinternals.h>
+#include <Rinternals.h>
+#undef error
+#undef length
 #include "data/ActorSet.h"
 #include "utils/Random.h"
 #include "BehaviorVariable.h"
@@ -29,8 +31,6 @@
 #include "model/ml/Chain.h"
 #include "model/ml/MiniStep.h"
 #include "model/ml/BehaviorChange.h"
-#include <Rinternals.h>
-
 
 using namespace std;
 
@@ -632,7 +632,7 @@ void BehaviorVariable::accumulateScores(int difference,
 			this->pSimulation()->score(pEffect->pEffectInfo()) + score);
 		if (R_IsNaN(score))
 		{
-			error("nan in accumulateScores1");
+			Rf_error("nan in accumulateScores1");
 		}
 	}
 
@@ -666,7 +666,7 @@ void BehaviorVariable::accumulateScores(int difference,
 		}
 		if (R_IsNaN(score))
 		{
-			error("nan in accumulateScores2");
+			Rf_error("nan in accumulateScores2");
 		}
 
 		this->pSimulation()->score(pEffect->pEffectInfo(),
@@ -695,7 +695,7 @@ void BehaviorVariable::accumulateScores(int difference,
 
 		if (R_IsNaN(score))
 		{
-			error("nan in accumulateScores3");
+			Rf_error("nan in accumulateScores3");
 		}
 
 		this->pSimulation()->score(pEffect->pEffectInfo(),
