@@ -10,7 +10,9 @@
  *****************************************************************************/
 #include <R_ext/Print.h>
 #include <R_ext/Arith.h>
-//#include <Rinternals.h>
+#include <Rinternals.h>
+#undef error
+#undef length
 #include <algorithm>
 #include <vector>
 #include <cmath>
@@ -43,7 +45,7 @@
 #include <vector>
 #include <cmath>
 
-#include <Rinternals.h>
+// #include <Rinternals.h> // already included
 #include <R_ext/Print.h>
 #include <R_ext/Arith.h>
 
@@ -789,7 +791,7 @@ void NetworkVariable::calculatePermissibleChanges()
 		int i = ii;
 		if (this->stepType() > -1) {
 			if (!iter->valid()) {
-				error( "size of iterator != size setting");
+				Rf_error( "size of iterator != size setting");
 			}
 			i = iter->actor();
 			iter->next();
@@ -887,7 +889,7 @@ void NetworkVariable::calculateTieFlipContributions()
 		if (this->stepType() != -1)
 		{
 			if (!permIter->valid()) {
-				error("permitted iter length != settings permitted size");
+				Rf_error("permitted iter length != settings permitted size");
 			}
 			alter = permIter->actor();
 			permIter->next();
@@ -1069,7 +1071,7 @@ void NetworkVariable::calculateTieFlipProbabilities()
 //		}
 //		else
 //		{
-//			error("setting not found");
+//			Rf_error("setting not found");
 //		}
 //		bool needEgo = true;
 //		if (row.size() == 0)
@@ -1204,7 +1206,7 @@ void NetworkVariable::calculateTieFlipProbabilities()
 			egoOutDegree = this->lpNetwork->outDegree(this->lego);
 			if (egoOutDegree > m)
 			{
-					error("outdegree > primary setting size");
+					Rf_error("outdegree > primary setting size");
 			}
 //			else if (egoOutDegree < m)
 //			{
@@ -1223,7 +1225,7 @@ void NetworkVariable::calculateTieFlipProbabilities()
 		{
 			if (!permIter->valid())
 			{
-				error( "permIter size differs from setting size");
+				Rf_error( "permIter size differs from setting size");
 			}
 			alter = permIter->actor();
 			permIter->next();
@@ -1309,7 +1311,7 @@ void NetworkVariable::calculateTieFlipProbabilities()
 		{
 			if (!permIter->valid()) 
 			{
-				error( "permitted iter length != settings permitted size");
+				Rf_error( "permitted iter length != settings permitted size");
 			}
 			alter = permIter->actor();
 			permIter->next();
@@ -1392,7 +1394,7 @@ void NetworkVariable::calculateTieFlipProbabilities()
 		Rprintf("this actor = %d\n", (this->lego + 1) );
 		Rprintf("this period = %d\n", (this->period() + 1) );
 		// counting starts at 0
-		error("total probability non-positive");
+		Rf_error("total probability non-positive");
 	}
 
 	// delete iter
@@ -1426,7 +1428,7 @@ void NetworkVariable::accumulateScores(int alter) const
 		if (alter >= m) {
 			Rprintf("this->n = %d this->m = %d m = %d alter = %d \n", this->n(),
 					this->m(), m, alter);
-		error("alter too large");
+		Rf_error("alter too large");
 	}
 	for (int h = 0; h < m; h++)
 	{
@@ -1435,7 +1437,7 @@ void NetworkVariable::accumulateScores(int alter) const
 	}
 	if (sumPermitted <= 0)
 	{
-		error("nothing was permitted");
+		Rf_error("nothing was permitted");
 	}
 	else if (sumPermitted >= 2)
 		// if sumPermitted == 1, no contribution to scores
@@ -1450,7 +1452,7 @@ void NetworkVariable::accumulateScores(int alter) const
 			{
 				Rprintf("R_IsNaN error: i = %d ego = %d alter = %d m = %d\n",
 					i, this->lego, alter, m);
-				error("nan score 41");
+				Rf_error("nan score 41");
 			}
 			if (curSetting) {
 				permIter->reset();
@@ -1464,7 +1466,7 @@ void NetworkVariable::accumulateScores(int alter) const
 				{
 					if (!permIter->valid())
 					{
-						error("iterator not valid");
+						Rf_error("iterator not valid");
 					}
 					j = permIter->actor();
 					permIter->next();
@@ -1496,14 +1498,14 @@ void NetworkVariable::accumulateScores(int alter) const
 							this->levaluationEffectContribution[j][i]);
 					Rprintf("R_IsNaN error: this->lprobabilities[j] = %f\n",
 							this->lprobabilities[j]);
-					error("nan score 1");
+					Rf_error("nan score 1");
 				}
 			}
 			if (R_IsNaN(this->pSimulation()->score(pEffect->pEffectInfo())))
 			{
 				Rprintf("R_IsNaN error: i = %d ego = %d alter = %d m = %d\n",
 					i, this->lego, alter, m);
-					error("nan score 0");
+					Rf_error("nan score 0");
 			}
 			this->pSimulation()->score(pEffect->pEffectInfo(),
 				this->pSimulation()->score(pEffect->pEffectInfo()) + score);
@@ -1534,7 +1536,7 @@ void NetworkVariable::accumulateScores(int alter) const
 				{
 					if (!permIter->valid())
 					{
-						error("iterator not valid");
+						Rf_error("iterator not valid");
 					}
 					j = permIter->actor();
 					permIter->next();
@@ -1574,7 +1576,7 @@ void NetworkVariable::accumulateScores(int alter) const
 				{
 					if (!permIter->valid())
 					{
-						error("iterator not valid");
+						Rf_error("iterator not valid");
 					}
 					j = permIter->actor();
 					permIter->next();
