@@ -15,7 +15,7 @@
  */
 #include <vector>
 #include <cstring>
-#include <Rinternals.h>
+// #include <Rinternals.h> // included by siena07internals.h
 #include "siena07internals.h"
 #include "data/Data.h"
 #include "data/LongitudinalData.h"
@@ -75,7 +75,7 @@ void getColNos(SEXP Names, int * netTypeCol, int * nameCol, int * effectCol,
 	*intptr3Col = -1;
 	*settingCol = -1;
 
-	int n = length(Names);
+	int n = Rf_length(Names);
 	for (int j = 0; j < n; j++)
 	{
 		if (strcmp(CHAR(STRING_ELT(Names, j)), "netType") == 0)
@@ -146,64 +146,64 @@ void getColNos(SEXP Names, int * netTypeCol, int * nameCol, int * effectCol,
 	}
 	if (*netTypeCol < 0)
 	{
-		error("cannot find nettype");
+		Rf_error("cannot find nettype");
 	}
 	if (*nameCol < 0)
 	{
-		error("cannot find network name");
+		Rf_error("cannot find network name");
 	}
 	if (*effectCol < 0)
 	{
-		error("cannot find effectName");
+		Rf_error("cannot find effectName");
 	}
 	if (*parmCol < 0)
 	{
-		error("cannot find internal parameter");
+		Rf_error("cannot find internal parameter");
 	}
 	if (*int1Col < 0)
 	{
-		error("cannot find interaction1");
+		Rf_error("cannot find interaction1");
         }
 
 	if (*int2Col < 0)
 	{
-		error("cannot find interaction2");
+		Rf_error("cannot find interaction2");
 	}
 	if (*initValCol < 0)
 	{
-		error("cannot find initial value");
+		Rf_error("cannot find initial value");
 	}
 	if (*groupCol < 0)
 	{
-		error("cannot find group");
+		Rf_error("cannot find group");
 	}
 	if (*periodCol < 0)
 	{
-		error("cannot find period");
+		Rf_error("cannot find period");
 	}
 	if (*pointerCol < 0)
 	{
-		error("cannot find effect pointer");
+		Rf_error("cannot find effect pointer");
 	}
 	if (*rateTypeCol < 0)
 	{
-		error("cannot find rate type");
+		Rf_error("cannot find rate type");
 	}
 	if (*intptr1Col < 0)
 	{
-		error("cannot find effect1");
+		Rf_error("cannot find effect1");
 	}
 	if (*intptr2Col < 0)
 	{
-		error("cannot find effect2");
+		Rf_error("cannot find effect2");
 	}
 	if (*intptr3Col < 0)
 	{
-		error("cannot find effect3");
+		Rf_error("cannot find effect3");
 	}
 	if (*settingCol < 0)
 	{
-		error("cannot find setting col; reconstruct effects object with this version of RSiena");
+		Rf_error("cannot find setting col; reconstruct effects object with this version of RSiena");
 	}
 	//Rprintf("%d parmcol\n", *parmCol);
 }
@@ -245,13 +245,13 @@ void updateParameters(SEXP EFFECTSLIST, SEXP THETA, vector<Data *> *
 
 	int thetasub = -1;
 	/* find each effect and update its weight */
-	for (int net = 0; net < length(EFFECTSLIST); net++)
+	for (int net = 0; net < Rf_length(EFFECTSLIST); net++)
 	{
 		const char * networkName =
 			CHAR(STRING_ELT(VECTOR_ELT(VECTOR_ELT(EFFECTSLIST, net),
 									   nameCol), 0));
 		SEXP EFFECTS = VECTOR_ELT(EFFECTSLIST, net);
-		for (int eff = 0; eff < length(VECTOR_ELT(EFFECTS,0)); eff++)
+		for (int eff = 0; eff < Rf_length(VECTOR_ELT(EFFECTS,0)); eff++)
 		{
 			thetasub = thetasub + 1;
 			const char * effectName =
@@ -303,7 +303,7 @@ void updateParameters(SEXP EFFECTSLIST, SEXP THETA, vector<Data *> *
 				 	}
 				 	else
 				 	{
-				 		error("setting found for behavior variable %s",
+				 		Rf_error("setting found for behavior variable %s",
 				 			networkName);
 				 	}
 				}
@@ -318,7 +318,7 @@ void updateParameters(SEXP EFFECTSLIST, SEXP THETA, vector<Data *> *
 				}
 			else
 			{
-					error("setting found for behavior variable %s", 
+					Rf_error("setting found for behavior variable %s", 
 						networkName);
 				}
 			}
@@ -411,10 +411,10 @@ void setupOneModeNetwork(SEXP ONEMODE,
 void setupOneModeObservations(const std::string& name, SEXP ONEMODES,
 		OneModeNetworkLongitudinalData * pOneModeNetworkLongitudinalData)
 {
-	int observations = length(ONEMODES);
+	int observations = Rf_length(ONEMODES);
 	if (observations != pOneModeNetworkLongitudinalData->observationCount())
 	{
-		error(("wrong number of observations in: " + name + ": expected "
+		Rf_error(("wrong number of observations in: " + name + ": expected "
 				+ toString(pOneModeNetworkLongitudinalData->observationCount()) + " got "
 				+ toString(observations)).c_str());
 	}
@@ -446,7 +446,7 @@ void setupOneModeObservations(const std::string& name, SEXP ONEMODES,
  */
 void setupOneModeGroup(SEXP ONEMODEGROUP, Data * pData)
 {
-	int nOneMode = length(ONEMODEGROUP);
+	int nOneMode = Rf_length(ONEMODEGROUP);
 
 	for (int oneMode = 0; oneMode < nOneMode; oneMode++)
 	{
@@ -473,14 +473,14 @@ void setupOneModeGroup(SEXP ONEMODEGROUP, Data * pData)
 		// parse settings
 		SEXP settingsSymbol = PROTECT(install("settingsinfo"));
 		SEXP settingsList = PROTECT(getAttrib(ONEMODES, settingsSymbol));
-		for (int j = 0; j < length(settingsList); j++)
+		for (int j = 0; j < Rf_length(settingsList); j++)
 		{
 			SEXP settingInfo = VECTOR_ELT(settingsList, j);
 			SEXP infoNames = getAttrib(settingInfo, R_NamesSymbol);
 			std::string id, type, covar, only;
 //			Rprintf("setting %d\n", j);
 			// parse key value list
-			for (int k = 0; k < length(settingInfo); k++) {
+			for (int k = 0; k < Rf_length(settingInfo); k++) {
 				// Rprintf("key value %d\n", k);
 				const char* key = CHAR(STRING_ELT(infoNames, k));
 				const char* value = CHAR(STRING_ELT(VECTOR_ELT(settingInfo, k), 0));
@@ -495,8 +495,8 @@ void setupOneModeGroup(SEXP ONEMODEGROUP, Data * pData)
 			if      (only == "up")   permType = Permission_Type::UP;
 			else if (only == "down") permType = Permission_Type::DOWN;
 			// asserts
-			if (id.length() == 0) error("settings id should not be empty");
-			if (type.length() == 0) error("settings type should not be empty");
+			if (id.length() == 0) Rf_error("settings id should not be empty");
+			if (type.length() == 0) Rf_error("settings type should not be empty");
 			// add it
 			Rprintf("%s %s %s %s\n", id.c_str(), type.c_str(), covar.c_str(), only.c_str());
 			pNetData->addSettingName(id, type, covar, permType);
@@ -504,12 +504,12 @@ void setupOneModeGroup(SEXP ONEMODEGROUP, Data * pData)
 
 		// check first two setting types
 		if (pNetData->rSettingNames().size() == 1) {
-			error("if setting are present use universal and primary");
+			Rf_error("if setting are present use universal and primary");
 		} else if (pNetData->rSettingNames().size() >= 2) {
 			if (pNetData->rSettingNames().at(0).getSettingType() != "universal")
-				error("first setting should be type=universal");
+				Rf_error("first setting should be type=universal");
 			if (pNetData->rSettingNames().at(1).getSettingType() != "primary")
-				error("second setting should be type=primary");
+				Rf_error("second setting should be type=primary");
 		}
 
 		pNetData->symmetric(*(LOGICAL(symmetric)));
@@ -626,10 +626,10 @@ void setupBipartiteObservations(SEXP BIPARTITES,
 	pNetworkLongitudinalData)
 
 {
-    int observations = length(BIPARTITES);
+    int observations = Rf_length(BIPARTITES);
     if (observations != pNetworkLongitudinalData->observationCount())
     {
-		error ("wrong number of observations in bipartite");
+		Rf_error ("wrong number of observations in bipartite");
     }
     SEXP uo;
     PROTECT(uo = install("uponly"));
@@ -658,7 +658,7 @@ void setupBipartiteObservations(SEXP BIPARTITES,
  */
 void setupBipartiteGroup(SEXP BIPARTITEGROUP, Data * pData)
 {
-	int nBipartite = length(BIPARTITEGROUP);
+	int nBipartite = Rf_length(BIPARTITEGROUP);
 
 	for (int bipartite = 0; bipartite < nBipartite; bipartite++)
 	{
@@ -701,13 +701,13 @@ void setupBehavior(SEXP BEHAVIOR, BehaviorLongitudinalData * pBehaviorData)
 
 	if (observations != pBehaviorData->observationCount())
 	{
-		error ("wrong number of observations in Behavior");
+		Rf_error ("wrong number of observations in Behavior");
 	}
 	int nActors = nrows(VECTOR_ELT(BEHAVIOR, 0));
 
 	if (nActors != pBehaviorData->n())
 	{
-		error ("wrong number of actors");
+		Rf_error ("wrong number of actors");
 	}
 	int * start = INTEGER(VECTOR_ELT(BEHAVIOR, 0));
 	int * missing = LOGICAL(VECTOR_ELT(BEHAVIOR, 1));
@@ -740,7 +740,7 @@ void setupBehavior(SEXP BEHAVIOR, BehaviorLongitudinalData * pBehaviorData)
 	SEXP simMeans = getAttrib(VECTOR_ELT(BEHAVIOR, 0), sims);
 	SEXP simNames;
 	PROTECT(simNames = getAttrib(simMeans, R_NamesSymbol));
-	int numberNetworks = length(simMeans);
+	int numberNetworks = Rf_length(simMeans);
 	for (int net = 0; net < numberNetworks; net++)
 	{
 		pBehaviorData->similarityMeans(REAL(simMeans)[net],
@@ -758,7 +758,7 @@ void setupBehavior(SEXP BEHAVIOR, BehaviorLongitudinalData * pBehaviorData)
  */
 void setupBehaviorGroup(SEXP BEHGROUP, Data *pData)
 {
-	int nBehavior = length(BEHGROUP);
+	int nBehavior = Rf_length(BEHGROUP);
 
 	for (int behavior= 0; behavior < nBehavior; behavior++)
 	{
@@ -793,13 +793,13 @@ void setupContinuous(SEXP CONTINUOUS, ContinuousLongitudinalData *
 
     if (observations != pContinuousData->observationCount())
     {
-		error ("wrong number of observations in Continuous");
+		Rf_error ("wrong number of observations in Continuous");
     }
     int nActors = nrows(VECTOR_ELT(CONTINUOUS, 0));
 
     if (nActors != pContinuousData->n())
     {
-        error ("wrong number of actors");
+        Rf_error ("wrong number of actors");
     }
     double * start = REAL(VECTOR_ELT(CONTINUOUS, 0));
 	int * missing = LOGICAL(VECTOR_ELT(CONTINUOUS, 1));
@@ -832,7 +832,7 @@ void setupContinuous(SEXP CONTINUOUS, ContinuousLongitudinalData *
 	SEXP simMeans = getAttrib(VECTOR_ELT(CONTINUOUS, 0), sims);
 	SEXP simNames;
 	PROTECT(simNames = getAttrib(simMeans, R_NamesSymbol));
-	int numberNetworks = length(simMeans);
+	int numberNetworks = Rf_length(simMeans);
 	for (int net = 0; net < numberNetworks; net++)
 	{
 		pContinuousData->similarityMeans(REAL(simMeans)[net],
@@ -849,7 +849,7 @@ void setupContinuous(SEXP CONTINUOUS, ContinuousLongitudinalData *
  */
 void setupContinuousGroup(SEXP CONTGROUP, Data *pData)
 {
-    int nCont = length(CONTGROUP);
+    int nCont = Rf_length(CONTGROUP);
 
     for (int continuous = 0; continuous < nCont; continuous++)
     {
@@ -878,7 +878,7 @@ void setupContinuousGroup(SEXP CONTGROUP, Data *pData)
 void setupConstantCovariate(SEXP COCOVAR,
 		ConstantCovariate * pConstantCovariate)
 {
-	int nActors = length(COCOVAR);
+	int nActors = Rf_length(COCOVAR);
 	// Rprintf("%x\n", pConstantCovariate);
 	double * start = REAL(COCOVAR);
 	SEXP mn;
@@ -941,7 +941,7 @@ void setupConstantCovariate(SEXP COCOVAR,
  */
 void setupConstantCovariateGroup(SEXP COCOVARGROUP, Data *pData)
 {
-	int nConstantCovariate = length(COCOVARGROUP);
+	int nConstantCovariate = Rf_length(COCOVARGROUP);
 	//    Rprintf("nConstantCovariate %d\n", nConstantCovariate);
 	for (int constantCovariate = 0; constantCovariate < nConstantCovariate;
 			constantCovariate++)
@@ -955,12 +955,12 @@ void setupConstantCovariateGroup(SEXP COCOVARGROUP, Data *pData)
 		SEXP name = getAttrib(VECTOR_ELT(COCOVARGROUP, constantCovariate), nm);
 		const ActorSet * pActorSet = pData->pActorSet(CHAR(STRING_ELT(
 						actorSet, 0)));
-		int nActors = length(VECTOR_ELT(COCOVARGROUP, constantCovariate));
+		int nActors = Rf_length(VECTOR_ELT(COCOVARGROUP, constantCovariate));
 		//    Rprintf("nactors %d\n", nActors);
 
 		if (nActors != pActorSet->n())
 		{
-			error ("wrong number of actors");
+			Rf_error ("wrong number of actors");
 		}
 		ConstantCovariate * pConstantCovariate =
 			pData->createConstantCovariate(CHAR(STRING_ELT(name, 0)),
@@ -993,7 +993,7 @@ void setupConstantCovariateGroup(SEXP COCOVARGROUP, Data *pData)
 				sims);
 		SEXP simNames;
 		PROTECT(simNames = getAttrib(simMeans, R_NamesSymbol));
-		int numberNetworks = length(simMeans);
+		int numberNetworks = Rf_length(simMeans);
 		for (int net = 0; net < numberNetworks; net++)
 		{
 			pConstantCovariate->similarityMeans(REAL(simMean)[net],
@@ -1088,14 +1088,14 @@ void setupChangingCovariate(SEXP VARCOVAR,
  */
 void setupChangingCovariateGroup(SEXP VARCOVARGROUP, Data *pData)
 {
-	if (length(VARCOVARGROUP) == 0)
+	if (Rf_length(VARCOVARGROUP) == 0)
 		return;
 	int observations = ncols(VECTOR_ELT(VARCOVARGROUP,0));
 	if (observations != pData->observationCount() - 1)
 	{
-		error ("wrong number of observations in Changing Covariate");
+		Rf_error ("wrong number of observations in Changing Covariate");
 	}
-	int nChangingCovariate = length(VARCOVARGROUP);
+	int nChangingCovariate = Rf_length(VARCOVARGROUP);
 	for (int changingCovariate = 0;
 			changingCovariate < nChangingCovariate;
 			changingCovariate++)
@@ -1114,7 +1114,7 @@ void setupChangingCovariateGroup(SEXP VARCOVARGROUP, Data *pData)
 
 		if (nActors != pActorSet->n())
 		{
-			error ("wrong number of actors");
+			Rf_error ("wrong number of actors");
 		}
 		ChangingCovariate * pChangingCovariate =
 			pData->createChangingCovariate(CHAR(STRING_ELT(name, 0)),
@@ -1147,7 +1147,7 @@ void setupChangingCovariateGroup(SEXP VARCOVARGROUP, Data *pData)
 				sims);
 		SEXP simNames;
 		PROTECT(simNames = getAttrib(simMeans, R_NamesSymbol));
-		int numberNetworks = length(simMeans);
+		int numberNetworks = Rf_length(simMeans);
 		for (int net = 0; net < numberNetworks; net++)
 		{
 			pChangingCovariate->similarityMeans(REAL(simMean)[net],
@@ -1204,7 +1204,7 @@ void setupDyadicCovariate(SEXP DYADVAR,
  */
 void setupDyadicCovariateGroup(SEXP DYADVARGROUP, Data *pData)
 {
-	int nDyadicCovariate = length(DYADVARGROUP);
+	int nDyadicCovariate = Rf_length(DYADVARGROUP);
 	//    Rprintf("nDyadicCovariate %d\n", nDyadicCovariate);
 	for (int dyadicCovariate = 0; dyadicCovariate < nDyadicCovariate;
 			dyadicCovariate++)
@@ -1278,10 +1278,10 @@ void unpackChangingDyadicPeriod(SEXP VARDYADVALS, ChangingDyadicCovariate *
 void setupChangingDyadicObservations(SEXP VARDYAD,
 		ChangingDyadicCovariate * pChangingDyadicCovariate)
 {
-	int observations = length(VARDYAD);
+	int observations = Rf_length(VARDYAD);
 	//   if (observations != pworkLongitudinalData->observationCount())
 	// {
-	//	error ("wrong number of observations in OneMode");
+	//	Rf_error ("wrong number of observations in OneMode");
 	//  }
 	for (int period = 0; period < (observations - 1); period++)
 	{
@@ -1296,7 +1296,7 @@ void setupChangingDyadicObservations(SEXP VARDYAD,
  */
 void setupChangingDyadicCovariateGroup(SEXP VARDYADGROUP, Data * pData)
 {
-	int nChangingDyadic = length(VARDYADGROUP);
+	int nChangingDyadic = Rf_length(VARDYADGROUP);
 
 	for (int changingDyadic = 0; changingDyadic < nChangingDyadic;
 			changingDyadic++)
@@ -1344,9 +1344,9 @@ void setupExogenousEventSet(SEXP EXOGEVENTSET, Data *pData)
 
 	/* now process the events */
 	SEXP EVENTS = VECTOR_ELT(EXOGEVENTSET, 0);
-	int nEvents = length(VECTOR_ELT(EVENTS, 0));
+	int nEvents = Rf_length(VECTOR_ELT(EVENTS, 0));
 	//Rprintf("number of rows of data frame %d\n",nEvents);
-	//Rprintf("%d\n", length(EVENTS));
+	//Rprintf("%d\n", Rf_length(EVENTS));
 	int * type = INTEGER(VECTOR_ELT(EVENTS, 0));
 	//Rprintf("type %d\n",*type);
 	int * period = INTEGER(VECTOR_ELT(EVENTS, 1));
@@ -1408,7 +1408,7 @@ void setupExogenousEventGroup(SEXP EXOGEVENTGROUP, Data *pData)
 		 Secondly a matrix of booleans, indicating whether active at start
 		 of period.*/
 
-	int nActorSets = length(EXOGEVENTGROUP);
+	int nActorSets = Rf_length(EXOGEVENTGROUP);
 	//	Rprintf("number of actor sets %d\n", nActorSets);
 
 	for (int actorSet = 0; actorSet < nActorSets; actorSet++)
@@ -1426,7 +1426,7 @@ SEXP createEffects(SEXP EFFECTS, Model *pModel, vector<Data *> * pGroupData,
 		int rateTypeCol, int netTypeCol, int settingCol)
 {
 	// find out how many effects there are
-	int nEffects = length(VECTOR_ELT(EFFECTS, 0));
+	int nEffects = Rf_length(VECTOR_ELT(EFFECTS, 0));
 
 	// create the effects
 
@@ -1493,7 +1493,7 @@ SEXP createEffects(SEXP EFFECTS, Model *pModel, vector<Data *> * pGroupData,
 				}
 				else
 				{
-					error("setting found for behavior variable %s",
+					Rf_error("setting found for behavior variable %s",
 							networkName);
 				}
 			}
@@ -1508,7 +1508,7 @@ SEXP createEffects(SEXP EFFECTS, Model *pModel, vector<Data *> * pGroupData,
 			}
 		else
 		{
-				error("setting found for variable %s", networkName);
+				Rf_error("setting found for variable %s", networkName);
 			}
 		}
 		else // no rate or scale effect
@@ -1540,7 +1540,7 @@ SEXP createInteractionEffects(SEXP EFFECTS, Model *pModel,
 		int typeCol, int intptr1Col, int intptr2Col, int intptr3Col)
 {
 	// find out how many effects there are
-	int nEffects = length(VECTOR_ELT(EFFECTS, 0));
+	int nEffects = Rf_length(VECTOR_ELT(EFFECTS, 0));
 
 	// create the effects
 
@@ -1622,11 +1622,11 @@ void getChangeContributionStatistics(SEXP EFFECTSLIST,
 			&rateTypeCol, &intptr1Col, &intptr2Col, &intptr3Col,
 			&settingCol);
 
-	for (int ii = 0; ii < length(EFFECTSLIST); ii++)
+	for (int ii = 0; ii < Rf_length(EFFECTSLIST); ii++)
 	{
 		SEXP EFFECTS = VECTOR_ELT(EFFECTSLIST, ii);
 
-		for (int i = 0; i < length(VECTOR_ELT(EFFECTS,0)); i++)
+		for (int i = 0; i < Rf_length(VECTOR_ELT(EFFECTS,0)); i++)
 		{
 			const char * effectType = CHAR(STRING_ELT(VECTOR_ELT(EFFECTS, typeCol), i));
 			const char * netType = CHAR(STRING_ELT(VECTOR_ELT(EFFECTS, netTypeCol), i));
@@ -1688,11 +1688,11 @@ void getActorStatistics(SEXP EFFECTSLIST,
 			&rateTypeCol, &intptr1Col, &intptr2Col, &intptr3Col,
 			&settingCol);
 
-	for (int ii = 0; ii < length(EFFECTSLIST); ii++)
+	for (int ii = 0; ii < Rf_length(EFFECTSLIST); ii++)
 	{
 		SEXP EFFECTS = VECTOR_ELT(EFFECTSLIST, ii);
 
-		for (int i = 0; i < length(VECTOR_ELT(EFFECTS,0)); i++)
+		for (int i = 0; i < Rf_length(VECTOR_ELT(EFFECTS,0)); i++)
 		{
 			const char * effectType = CHAR(STRING_ELT(VECTOR_ELT(EFFECTS, typeCol), i));
 			const char * netType = CHAR(STRING_ELT(VECTOR_ELT(EFFECTS, netTypeCol), i));
@@ -1758,14 +1758,14 @@ void getStatistics(SEXP EFFECTSLIST,
 	double score = 0;
 	int istore = 0;
 
-	for (int ii = 0; ii < length(EFFECTSLIST); ii++)
+	for (int ii = 0; ii < Rf_length(EFFECTSLIST); ii++)
 	{
 		const char * networkName =
 			CHAR(STRING_ELT(VECTOR_ELT(VECTOR_ELT(EFFECTSLIST, ii),
 							nameCol), 0));
 		SEXP EFFECTS = VECTOR_ELT(EFFECTSLIST, ii);
 
-		for (int i = 0; i < length(VECTOR_ELT(EFFECTS,0)); i++)
+		for (int i = 0; i < Rf_length(VECTOR_ELT(EFFECTS,0)); i++)
 		{
 			const char * effectName =
 				CHAR(STRING_ELT(VECTOR_ELT(EFFECTS, effectCol),  i));
@@ -1957,7 +1957,7 @@ void getStatistics(SEXP EFFECTSLIST,
 						else
 						{
 
-							error("Unexpected rate effect %s\n",
+							Rf_error("Unexpected rate effect %s\n",
 									effectName);
 						}
 					}
@@ -1988,7 +1988,7 @@ void getStatistics(SEXP EFFECTSLIST,
 						}
 						else
 						{
-							error("Unexpected rate effect %s\n",
+							Rf_error("Unexpected rate effect %s\n",
 									effectName);
 						}
 					}
@@ -2036,7 +2036,7 @@ void getStatistics(SEXP EFFECTSLIST,
 						}
 						else
 						{
-							error("No individual covariate named %s.",
+							Rf_error("No individual covariate named %s.",
 									interaction1);
 						}
 					}
@@ -2119,7 +2119,7 @@ void getStatistics(SEXP EFFECTSLIST,
 				}
 				else
 				{
-					error("invalid effect type %s\n", effectType);
+					Rf_error("invalid effect type %s\n", effectType);
 				}
 			}
 			(*rfra)[istore] = statistic;
@@ -2175,14 +2175,14 @@ void getScores(SEXP EFFECTSLIST, int period, int group,
 	int storescore = 0;
 	int storederiv = 0;
 
-	for (int ii = 0; ii < length(EFFECTSLIST); ii++)
+	for (int ii = 0; ii < Rf_length(EFFECTSLIST); ii++)
 	{
 		const char * networkName =
 			CHAR(STRING_ELT(VECTOR_ELT(VECTOR_ELT(EFFECTSLIST, ii),
 							nameCol), 0));
 		SEXP EFFECTS = VECTOR_ELT(EFFECTSLIST, ii);
 
-		for (int i = 0; i < length(VECTOR_ELT(EFFECTS,0)); i++)
+		for (int i = 0; i < Rf_length(VECTOR_ELT(EFFECTS,0)); i++)
 		{
 			const char * effectName =
 				CHAR(STRING_ELT(VECTOR_ELT(EFFECTS, effectCol),  i));
@@ -2212,7 +2212,7 @@ void getScores(SEXP EFFECTSLIST, int period, int group,
 				}
 				else
 				{
-					error("Non constant rate effects are not yet %s",
+					Rf_error("Non constant rate effects are not yet %s",
 							"implemented for maximum likelihood.");
 				}
 			}
@@ -2227,7 +2227,7 @@ void getScores(SEXP EFFECTSLIST, int period, int group,
 				map<const EffectInfo *, double > deriv =
 					pMLSimulation->derivative(pEffectInfo);
 
-				for (int j = 0; j < length(VECTOR_ELT(EFFECTS,0)); j++)
+				for (int j = 0; j < Rf_length(VECTOR_ELT(EFFECTS,0)); j++)
 				{
 					const char * effectType =
 						CHAR(STRING_ELT(VECTOR_ELT(EFFECTS, typeCol), j));
