@@ -13,6 +13,8 @@
 #define SIENA07UTILITIES_H_
 
 #include <Rinternals.h>
+#undef error
+#undef length
 
 #include "network/Network.h"
 #include "model/variables/DependentVariable.h"
